@@ -3,8 +3,12 @@ import logging
 import os
 from .i18n import get_text
 from .maid import attend, start
-from .action.kill_proc import kill_process
+from .action.kill_process import kill_process
 from .action.stop_service import stop_service
+from .action.lock_volume import lock_volume
+from .action.alarm import alarm
+from .action.write_file import write_file
+from .action.get_top_processes import get_top_processes
 
 logger = logging.getLogger(__name__)
 
@@ -43,6 +47,10 @@ __all__ = [
     "attend",
     "kill_process",
     "stop_service",
+    "lock_volume",
+    "alarm",
+    "write_file",
+    "get_top_processes",
     "start",
     "set_log_level",
 ]
\ No newline at end of file
